==> haskell-ghc-typelits-extra-0.4.4-51-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ghc-typelits-extra.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 ghc-typelits-extra
version:              0.4.4
visibility:           public
id:                   ghc-typelits-extra-0.4.4-LDohp2PXewb32k4GBBzm9E
key:                  ghc-typelits-extra-0.4.4-LDohp2PXewb32k4GBBzm9E
license:              BSD-2-Clause
copyright:
    Copyright © 2015-2016, University of Twente,
    2017-2018, QBayLogic B.V.

maintainer:           christiaan.baaij@gmail.com
author:               Christiaan Baaij
homepage:             http://www.clash-lang.org/
synopsis:             Additional type-level operations on GHC.TypeLits.Nat
description:
    Additional type-level operations on @GHC.TypeLits.Nat@:

    * @Max@: type-level <http://hackage.haskell.org/package/base-4.8.2.0/docs/Prelude.html#v:max max>

    * @Min@: type-level <http://hackage.haskell.org/package/base-4.8.2.0/docs/Prelude.html#v:min min>

    * @Div@: type-level <http://hackage.haskell.org/package/base-4.8.2.0/docs/Prelude.html#v:div div>

    * @Mod@: type-level <http://hackage.haskell.org/package/base-4.8.2.0/docs/Prelude.html#v:mod mod>

    * @FLog@: type-level equivalent of <https://hackage.haskell.org/package/integer-gmp/docs/GHC-Integer-Logarithms.html#v:integerLogBase-35- integerLogBase#>
    i.e. the exact integer equivalent to @floor (logBase x y)@

    * @CLog@: type-level equivalent of /the ceiling of/ <https://hackage.haskell.org/package/integer-gmp/docs/GHC-Integer-Logarithms.html#v:integerLogBase-35- integerLogBase#>
    i.e. the exact integer equivalent to @ceiling (logBase x y)@

    * @Log@: type-level equivalent of <https://hackage.haskell.org/package/integer-gmp/docs/GHC-Integer-Logarithms.html#v:integerLogBase-35- integerLogBase#>
    where the operation only reduces when @floor (logBase b x) ~ ceiling (logBase b x)@

    * @GCD@: a type-level <http://hackage.haskell.org/package/base-4.8.2.0/docs/Prelude.html#v:gcd gcd>

    * @LCM@: a type-level <http://hackage.haskell.org/package/base-4.8.2.0/docs/Prelude.html#v:lcm lcm>

    And a custom solver for the above operations defined in
    @GHC.TypeLits.Extra.Solver@ as a GHC type-checker plugin. To use the plugin,
    add the

    @
    OPTIONS_GHC -fplugin GHC.TypeLits.Extra.Solver
    @

    pragma to the header of your file.

category:             Type System
abi:                  4dc0ef2ee68604237c199b95ff944028
exposed:              True
exposed-modules:      GHC.TypeLits.Extra GHC.TypeLits.Extra.Solver
hidden-modules:
    GHC.TypeLits.Extra.Solver.Unify
    GHC.TypeLits.Extra.Solver.Operations

import-dirs:          /usr/lib/ghc-9.2.8/site-local/ghc-typelits-extra-0.4.4
library-dirs:         /usr/lib/ghc-9.2.8/site-local/ghc-typelits-extra-0.4.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ghc-typelits-extra
hs-libraries:         HSghc-typelits-extra-0.4.4-LDohp2PXewb32k4GBBzm9E
depends:
    base-4.16.4.0 containers-0.6.5.1 ghc-9.2.8 ghc-bignum-1.2
    ghc-prim-0.8.0 ghc-tcplugins-extra-0.4.6-9uHiztiXkouG86ImZZc9vs
    ghc-typelits-knownnat-0.7.8-GJp6U1Zdddf5oXGgdrXodS
    ghc-typelits-natnormalise-0.7.8-8UuyPBwxdUq7uvgYksKp20
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-ghc-typelits-extra/html/ghc-typelits-extra.haddock

haddock-html:         /usr/share/doc/haskell-ghc-typelits-extra/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ghc-typelits-extra-0.4.4-53-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ghc-typelits-extra.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ghc-typelits-extra
version:              0.4.4
visibility:           public
id:                   ghc-typelits-extra-0.4.4-LWUk66QtBbPC8zRw2n5TyM
key:                  ghc-typelits-extra-0.4.4-LWUk66QtBbPC8zRw2n5TyM
license:              BSD-2-Clause
copyright:
    Copyright © 2015-2016, University of Twente,
    2017-2018, QBayLogic B.V.

maintainer:           christiaan.baaij@gmail.com
author:               Christiaan Baaij
homepage:             http://www.clash-lang.org/
synopsis:             Additional type-level operations on GHC.TypeLits.Nat
description:
    Additional type-level operations on @GHC.TypeLits.Nat@:

    * @Max@: type-level <http://hackage.haskell.org/package/base-4.8.2.0/docs/Prelude.html#v:max max>

    * @Min@: type-level <http://hackage.haskell.org/package/base-4.8.2.0/docs/Prelude.html#v:min min>

    * @Div@: type-level <http://hackage.haskell.org/package/base-4.8.2.0/docs/Prelude.html#v:div div>

    * @Mod@: type-level <http://hackage.haskell.org/package/base-4.8.2.0/docs/Prelude.html#v:mod mod>

    * @FLog@: type-level equivalent of <https://hackage.haskell.org/package/integer-gmp/docs/GHC-Integer-Logarithms.html#v:integerLogBase-35- integerLogBase#>
    i.e. the exact integer equivalent to @floor (logBase x y)@

    * @CLog@: type-level equivalent of /the ceiling of/ <https://hackage.haskell.org/package/integer-gmp/docs/GHC-Integer-Logarithms.html#v:integerLogBase-35- integerLogBase#>
    i.e. the exact integer equivalent to @ceiling (logBase x y)@

    * @Log@: type-level equivalent of <https://hackage.haskell.org/package/integer-gmp/docs/GHC-Integer-Logarithms.html#v:integerLogBase-35- integerLogBase#>
    where the operation only reduces when @floor (logBase b x) ~ ceiling (logBase b x)@

    * @GCD@: a type-level <http://hackage.haskell.org/package/base-4.8.2.0/docs/Prelude.html#v:gcd gcd>

    * @LCM@: a type-level <http://hackage.haskell.org/package/base-4.8.2.0/docs/Prelude.html#v:lcm lcm>

    And a custom solver for the above operations defined in
    @GHC.TypeLits.Extra.Solver@ as a GHC type-checker plugin. To use the plugin,
    add the

    @
    OPTIONS_GHC -fplugin GHC.TypeLits.Extra.Solver
    @

    pragma to the header of your file.

category:             Type System
abi:                  fb2b45affad6c63f412e640141f47151
exposed:              True
exposed-modules:      GHC.TypeLits.Extra GHC.TypeLits.Extra.Solver
hidden-modules:
    GHC.TypeLits.Extra.Solver.Unify
    GHC.TypeLits.Extra.Solver.Operations

import-dirs:          /usr/lib/ghc-9.4.8/site-local/ghc-typelits-extra-0.4.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/ghc-typelits-extra-0.4.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/ghc-typelits-extra-0.4.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ghc-typelits-extra
hs-libraries:         HSghc-typelits-extra-0.4.4-LWUk66QtBbPC8zRw2n5TyM
depends:
    base-4.17.2.1 containers-0.6.7 ghc-9.4.8 ghc-bignum-1.3
    ghc-prim-0.9.1 ghc-tcplugins-extra-0.4.6-7NSTPRMOQMZAWGxM8BIEYE
    ghc-typelits-knownnat-0.7.8-AidJOZHnyTHxvrBfdBZ1c
    ghc-typelits-natnormalise-0.7.8-EpR4QncKfbiJBIuqIq5ame
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-ghc-typelits-extra/html/ghc-typelits-extra.haddock

haddock-html:         /usr/share/doc/haskell-ghc-typelits-extra/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
